import pytest

from gptables.core.cover import Cover


class TestCover:

    @pytest.mark.parametrize(
        "input_data",
        [
            None,
            ["text"],
            [[{"bold": True}, "richtext"]],
            [[{"bold": True}, "richtext", " "]],
            [[{"bold": True}, "richtext", " "], "text"],
            "text",
            42,
            [15],
        ],
    )
    def test_parse_formatting(self, input_data):

        got = Cover._parse_formatting(input_data)

        if isinstance(input_data, list):
            assert all(
                [
                    got_element.list == input_element
                    for input_element, got_element in zip(input_data, got)
                    if isinstance(input_element, list)
                ]
            )

        else:
            assert got == input_data



import glob
import pickle  # nosec B403
from os.path import abspath, basename, dirname, join, splitext

import gptables.core.theme


def pickle_themes():
    """
    Utility function for updating theme pickles.
    """
    package_dir = dirname(dirname(dirname(abspath(__file__))))
    theme_configs = glob.glob(join(package_dir, "gptables", "themes", "*.yaml"))

    pickled_output_dir = join(package_dir, "gptables", "theme_pickles")

    for cfg in theme_configs:
        file, ext = splitext(basename(cfg))
        out_file = join(pickled_output_dir, (file + ".pickle"))

        theme = gptables.core.theme.Theme(cfg)

        pickle.dump(theme, open(out_file, "wb"))


if __name__ == "__main__":
    pickle_themes()



import pandas as pd
import pytest

from gptables.core.gptable import GPTable


@pytest.fixture(scope="function")
def create_gptable_with_kwargs():

    def generate_gptable(format_dict=None):
        base_gptable = {
            "table": pd.DataFrame(),
            "table_name": "table_name",
            "title": "",
            "index_columns": {},  # Override default, as no columns in table
        }
        if format_dict is not None:
            base_gptable.update(format_dict)
        return GPTable(**base_gptable)

    return generate_gptable
